@@ -286,7 +286,7 @@ resolve_address (const gchar* address, GError** err)
 
   if (root_dir == NULL)
     {
-      gconf_set_error(err, GCONF_ERROR_BAD_ADDRESS, _("Couldn't find the XML root directory in the address `%s'"), address);
+      gconf_set_error (err, GCONF_ERROR_BAD_ADDRESS, _("Couldn't find the root directory in the address \"%s\""), address);
       return NULL;
     }
 
@@ -411,7 +411,7 @@ resolve_address (const gchar* address, GError** err)
   if (!(flags & GCONF_SOURCE_ALL_READABLE) &&
       !(flags & GCONF_SOURCE_ALL_WRITEABLE))
     {
-      gconf_set_error(err, GCONF_ERROR_BAD_ADDRESS, _("Can't read from or write to the XML root directory in the address `%s'"), address);
+      gconf_set_error(err, GCONF_ERROR_BAD_ADDRESS, _("Can't read from or write to the XML root directory in the address \"%s\""), address);
       g_free(root_dir);
       return NULL;
     }  
@@ -787,7 +787,7 @@ xs_destroy   (XMLSource* xs)
      situation */
   if (xs->lock != NULL && !gconf_release_lock(xs->lock, &error))
     {
-      gconf_log(GCL_ERR, _("Failed to give up lock on XML dir `%s': %s"),
+      gconf_log(GCL_ERR, _("Failed to give up lock on XML dir \"%s\": %s"),
                 xs->root_dir, error->message);
       g_error_free(error);
       error = NULL;
