@@ -374,11 +374,14 @@ dir_sync (Dir      *d,
           return FALSE;
         }
 
-      if (rmdir (d->fs_dirname) != 0)
+      if (strcmp (d->key, "/") != 0) /* don't delete root dir */
         {
-          gconf_set_error (err, GCONF_ERROR_FAILED, _("Failed to delete \"%s\": %s"),
-                           d->fs_dirname, strerror (errno));
-          return FALSE;
+          if (rmdir (d->fs_dirname) != 0)
+            {
+              gconf_set_error (err, GCONF_ERROR_FAILED, _("Failed to delete \"%s\": %s"),
+                               d->fs_dirname, strerror (errno));
+              return FALSE;
+            }
         }
 
       if (deleted)
@@ -562,7 +565,7 @@ dir_get_value   (Dir* d,
                  GError** err)
 {
   Entry* e;
-
+  
   if (d->doc == NULL)
     dir_load_doc(d, err);
 
@@ -1206,8 +1209,8 @@ create_fs_dir(const gchar* dir, const gchar* xml_filename,
       if (errno != EEXIST)
         {
           gconf_set_error(err, GCONF_ERROR_FAILED,
-                          _("Could not make directory `%s': %s"),
-                          (gchar*)dir, strerror(errno));
+                          _("Could not make directory \"%s\": %s"),
+                          (gchar*)dir, g_strerror(errno));
           return FALSE;
         }
     }
@@ -1299,7 +1302,7 @@ my_xml_parse_file (const char *filename,
                    GError    **err)
 {
   char *text;
-  int length;
+  gsize length;
   xmlDocPtr doc;
   
   text = NULL;
