@@ -798,7 +798,7 @@ subst_variables(const gchar* src)
 
               if ((retval_len - pos) < varval_len)
                 {
-                  retval_len *= 2;
+                  retval_len = pos + varval_len;
                   retval = g_realloc(retval, retval_len+3);
                 }
               
@@ -1355,7 +1355,7 @@ gconf_value_list_to_primitive_list_destructive(GConfValue* val,
         *err = gconf_error_new(GCONF_ERROR_TYPE_MISMATCH,
                                _("Expected list of %s, got list of %s"),
                                gconf_value_type_to_string(list_type),
-                               gconf_value_type_to_string(val->type));
+                               gconf_value_type_to_string(gconf_value_get_list_type (val)));
       gconf_value_free(val);
       return NULL;
     }
@@ -2374,6 +2374,7 @@ open_empty_locked_file (const gchar *directory,
     }
 
   /* We have the lock on filename, so delete it */
+  /* FIXME this leaves .nfs32423432 cruft */
   unlink (filename);
   close (fd);
   fd = -1;
@@ -2860,7 +2861,7 @@ gconf_activate_server (gboolean  start_if_not_found,
           goto out;
         }
 
-      argv[0] = g_strconcat (GCONF_BINDIR, "/" GCONFD, NULL);
+      argv[0] = g_strconcat (GCONF_SERVERDIR, "/" GCONFD, NULL);
       argv[1] = g_strdup_printf ("%d", p[1]);
       argv[2] = NULL;
   
